@@ -18,18 +18,25 @@
 
 package Software::License::AGPL_3::or_later;
 
-# ABSTRACT: Add-on for Software::License module providing "or any later" clause to AGPL_3
+# ABSTRACT: AGPLv3+ license for Software::License
 
 use strict;
 use warnings;
 
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
-use parent 'Software::License::AGPL_3';
+use parent __PACKAGE__ =~ m{\A(.*)::or_later\z};
+use Software::License::GPL_3::or_later;
 
-sub name { $_[ 0 ]->SUPER::name() . ', or any later' };
-sub version { '3+'; };
-    #   Cannot call `$-[ 0 ]->SUPER::version()` here because it returns "later".
+# The name of the license.
+sub _name { 'the GNU Affero General Public License'; };
+
+# All other methods are exactly the same as methods in `Software::License::GPL_3::or_later`, so let
+# us delegate the work.
+foreach ( qw{ _version name version notice } ) {
+    no strict 'refs';
+    *{ $_ } = \&{ "Software::License::GPL_3::or_later::$_" };
+}; # foreach
 
 1;
 
@@ -37,59 +44,33 @@ sub version { '3+'; };
 #pod
 #pod =head1 DESCRIPTION
 #pod
-#pod C<Software::License::AGPL_3::or_later> is a subclass of L<Software::License::AGPL_3>. It overrides
-#pod few parent methods:
-#pod
-#pod =for :list
-#pod = C<name>
-#pod appends ", or any later" clause to the parent license name;
-#pod = C<version>
-#pod appends "+" to the parent license version;
-#pod = C<notice>
-#pod returns copyright statement and standard GNU 3-paragraph notice.
-#pod
-#pod See documentation on L<Software::License> for a general description of class interface.
+#pod See documentation on L<Software::License::GPL_3::or_later>. This module does the same but provides
+#pod the GNU Affero General Public License.
 #pod
 #pod =cut
 
+# TODO: It would be nice to eliminate __DATA__ section as well.
+
 =pod
 
 =encoding UTF-8
 
 =head1 NAME
 
-Software::License::AGPL_3::or_later - Add-on for Software::License module providing "or any later" clause to AGPL_3
+Software::License::AGPL_3::or_later - AGPLv3+ license for Software::License
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
-C<Software::License::AGPL_3::or_later> is a subclass of L<Software::License::AGPL_3>. It overrides
-few parent methods:
-
-=over 4
-
-=item C<name>
-
-appends ", or any later" clause to the parent license name;
-
-=item C<version>
-
-appends "+" to the parent license version;
-
-=item C<notice>
-
-returns copyright statement and standard GNU 3-paragraph notice.
-
-=back
-
-See documentation on L<Software::License> for a general description of class interface.
+See documentation on L<Software::License::GPL_3::or_later>. This module does the same but provides
+the GNU Affero General Public License.
 
 =head1 AUTHOR
 
-Van de Bugger <van.de.bugger@liamg.moc>
+Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -111,20 +92,19 @@ this program.  If not, see <http://www.gnu.org/licenses/>.
 
 __DATA__
 __NOTICE__
-Copyright (C) {{$self->year}} {{$self->holder}}
+Copyright (C) {{ $self->year }} {{ $self->holder }}
 
-This program is free software: you can redistribute it and/or modify it under
-the terms of the GNU Affero General Public License as published by the Free
-Software Foundation, either version 3 of the License, or (at your option) any
-later version.
+{{ ucfirst( $self->{ program } ) }} is free software: you can redistribute it and/or modify it
+under the terms of {{ $self->_name }} as published by the Free Software Foundation, either version
+{{ $self->_version }} of the License, or (at your option) any later version.
 
-This program is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
-details.
+{{ ucfirst( $self->{ program } ) }} is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+PURPOSE. See {{ $self->_name }} for more details.
+
+You should have received a copy of {{ $self->_name }} along with {{ $self->{ program } }}. If not,
+see <http://www.gnu.org/licenses/>.
 
-You should have received a copy of the GNU Affero General Public License along
-with this program.  If not, see <http://www.gnu.org/licenses/>.
 __END__
 
 # end of file #
