@@ -18,13 +18,13 @@
 
 package Software::License::OrLaterPack;
 
-# ABSTRACT: Add-ons for Software::License module providing "or any later" clause to some GNU licenses
+# ABSTRACT: GPLv3+ and AGPLv3+ for Software::License
 
 use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use Software::License::AGPL_3::or_later;
 use Software::License::GPL_3::or_later;
@@ -61,23 +61,24 @@ use Software::License::GPL_3::or_later;
 #pod
 #pod =head1 PURPOSE
 #pod
-#pod L<Dist::Zilla>/C<dzil>, a popular framework/tool for building packages for CPAN, allows you to
-#pod specify software license in C<dist.ini> file, e. g.:
+#pod L<Dist::Zilla>, a popular tool for building packages for CPAN, allows you to specify software
+#pod license for your distribution in C<dist.ini> file, e. g.:
 #pod
 #pod     license = NAME
 #pod
 #pod where I<NAME> is a short license name, like C<Perl_5> or C<BSD>. When building your package,
 #pod C<dzil> will add "COPYRIGHT AND LICENSE" section to the documentation, add appropriate C<LICENSE>
-#pod file to your package, etc. C<Dist::Zilla> uses licenses provided by C<Software::License> package.
-#pod The latter is bundled with a set of popular software licenses, including GNU General Public License
-#pod (GNU GPL) versions 1, 2, and 3, denoted by names C<GPL_1>, C<GPL_2>, and C<GPL_3> respectively.
+#pod file to your distribution, etc. C<Dist::Zilla> uses licenses provided by C<Software::License>
+#pod module. The latter is shipped with a set of popular software licenses, including GNU General Public
+#pod License (GNU GPL) versions 1, 2, and 3, denoted by names C<GPL_1>, C<GPL_2>, and C<GPL_3>
+#pod respectively.
 #pod
-#pod L<Free Software Foundation|https://fsf.org/>, a developer of GNU GPL, recommends do not stick to a
-#pod specific version of the GNU license, but allow "upgrading" it by using "license version I<N> or (at
-#pod your option) any later version". See
+#pod L<Free Software Foundation|https://fsf.org/>, a developer of GNU GPL, recommends not to stick to a
+#pod specific version of the GNU license, but allow "upgrading" it by using clause "license version I<N>
+#pod or (at your option) any later version". See the
 #pod L<rationale|https://www.gnu.org/licenses/gpl-faq.html#VersionThreeOrLater>.
 #pod
-#pod However, L<Software::License> package does not provide (ready to use out of the box) a way to
+#pod However, L<Software::License> distribution does not provide (ready to use out of the box) a way to
 #pod express such conditions. This module partially fulfills the lack.
 #pod
 #pod =head1 LIST OF PROVIDED LICENSES
@@ -86,7 +87,7 @@ use Software::License::GPL_3::or_later;
 #pod = L<Software::License::AGPL_3::or_later>
 #pod = L<Software::License::GPL_3::or_later>
 #pod
-#pod Let me know if you need other licenses, e. g. GPLv2+.
+#pod Let me know if you need other licenses, e. g. GPLv2+ or LGPLv3+.
 #pod
 #pod =head1 CAVEATS
 #pod
@@ -117,11 +118,11 @@ __END__
 
 =head1 NAME
 
-Software::License::OrLaterPack - Add-ons for Software::License module providing "or any later" clause to some GNU licenses
+Software::License::OrLaterPack - GPLv3+ and AGPLv3+ for Software::License
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -149,23 +150,24 @@ Direct usage:
 
 =head1 PURPOSE
 
-L<Dist::Zilla>/C<dzil>, a popular framework/tool for building packages for CPAN, allows you to
-specify software license in C<dist.ini> file, e. g.:
+L<Dist::Zilla>, a popular tool for building packages for CPAN, allows you to specify software
+license for your distribution in C<dist.ini> file, e. g.:
 
     license = NAME
 
 where I<NAME> is a short license name, like C<Perl_5> or C<BSD>. When building your package,
 C<dzil> will add "COPYRIGHT AND LICENSE" section to the documentation, add appropriate C<LICENSE>
-file to your package, etc. C<Dist::Zilla> uses licenses provided by C<Software::License> package.
-The latter is bundled with a set of popular software licenses, including GNU General Public License
-(GNU GPL) versions 1, 2, and 3, denoted by names C<GPL_1>, C<GPL_2>, and C<GPL_3> respectively.
+file to your distribution, etc. C<Dist::Zilla> uses licenses provided by C<Software::License>
+module. The latter is shipped with a set of popular software licenses, including GNU General Public
+License (GNU GPL) versions 1, 2, and 3, denoted by names C<GPL_1>, C<GPL_2>, and C<GPL_3>
+respectively.
 
-L<Free Software Foundation|https://fsf.org/>, a developer of GNU GPL, recommends do not stick to a
-specific version of the GNU license, but allow "upgrading" it by using "license version I<N> or (at
-your option) any later version". See
+L<Free Software Foundation|https://fsf.org/>, a developer of GNU GPL, recommends not to stick to a
+specific version of the GNU license, but allow "upgrading" it by using clause "license version I<N>
+or (at your option) any later version". See the
 L<rationale|https://www.gnu.org/licenses/gpl-faq.html#VersionThreeOrLater>.
 
-However, L<Software::License> package does not provide (ready to use out of the box) a way to
+However, L<Software::License> distribution does not provide (ready to use out of the box) a way to
 express such conditions. This module partially fulfills the lack.
 
 =head1 LIST OF PROVIDED LICENSES
@@ -178,7 +180,7 @@ express such conditions. This module partially fulfills the lack.
 
 =back
 
-Let me know if you need other licenses, e. g. GPLv2+.
+Let me know if you need other licenses, e. g. GPLv2+ or LGPLv3+.
 
 =head1 CAVEATS
 
@@ -208,7 +210,7 @@ so on.
 
 =head1 AUTHOR
 
-Van de Bugger <van.de.bugger@liamg.moc>
+Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
